import pytest
from my_platform_sdk_package.http_client import ApiError
from config import  BASE_URL, MODEL_ID,LIMIT, OFFSET, TASK_ID, FROM, TO, COMMIT_HASH, VERIFY_STATUS


@pytest.mark.parametrize("model_id, offset, limit, verify_status, expect_success", [
    ("7332d265-171e-4055-9f2f-af51a52a82c4", 0, 5, "verified", True),
    ("7332d265-171e-4055-9f2f-af51a52a82c4", -9, 5, "verified", False),
])
def test_get_list_verified_model_versioning(api_key_model_versioning_service, model_id, offset, limit, verify_status, expect_success):
    try:
        resp = api_key_model_versioning_service.get_list_verified_model_versioning(
            model_id, offset, limit, verify_status
        )
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected ApiError: {e}")
        else:
            assert "offset" in str(e).lower(), f"Expected offset validation error, got {e}"



@pytest.mark.parametrize("model_id, commit_hash, expect_success", [
    (MODEL_ID, COMMIT_HASH, False),
])
def test_change_current_model_versioning(api_key_model_versioning_service, model_id, commit_hash, expect_success):
    try:
        resp = api_key_model_versioning_service.change_current_model_versioning_by_model_id_and_commit_hash(
            model_id, commit_hash
        )
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
    except ApiError as e:
        assert "verified model versioning not exist" in str(e).lower(), \
                f"Expected 'verified model versioning not exist' in error, got {e}"





import pytest
from config import TASK_ID
from my_platform_sdk_package.http_client import ApiError
from aioz_api_client.models.request_check_valid_to_verify_ai_model_request import RequestCheckValidToVerifyAiModelRequest
from config import API_KEY, BASE_URL, MODEL_ID,LIMIT, OFFSET, TASK_ID, FROM, TO, COMMIT_HASH, VERIFY_STATUS, PLATFORMS
from aioz_api_client.models.request_verify_ai_model_request import RequestVerifyAiModelRequest
from aioz_api_client.models.request_calculate_cost_to_verify_ai_model_request import RequestCalculateCostToVerifyAiModelRequest


@pytest.mark.parametrize(
    "model_id, commit_hash, platforms, expect_success",
    [
        (MODEL_ID, COMMIT_HASH, PLATFORMS, False),
    ]
)
def test_calculate_cost_to_verify_model(api_key_model_verify_service, model_id, commit_hash, platforms, expect_success):
    request_obj = RequestCalculateCostToVerifyAiModelRequest(
        commit_hash=commit_hash,
        platforms=platforms
    )
    try:
        resp = api_key_model_verify_service.calculate_cost_to_verify_model(model_id, request_obj)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")
        else:
            assert "please set up model setting" in str(e).lower(), f"Expected setup error, got {e}"



@pytest.mark.parametrize(
    "model_id, commit_hash, platforms, expect_success",
    [
        (MODEL_ID, COMMIT_HASH, PLATFORMS, True),
    ]
)
def test_verify_model(api_key_model_verify_service, model_id, commit_hash, platforms, expect_success):
    request_obj = RequestVerifyAiModelRequest(
        commit_hash=commit_hash,
        platforms=platforms
    )
    try:
        resp= api_key_model_verify_service.verify_model(model_id, request_obj)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
       if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")


@pytest.mark.parametrize(
    "model_id, commit_hash, platforms, expect_success",
    [
        (MODEL_ID, COMMIT_HASH, PLATFORMS, False),
    ]
)
def test_pre_check_to_verify_model(api_key_model_verify_service, model_id, commit_hash, platforms, expect_success):
    request_obj = RequestCheckValidToVerifyAiModelRequest(
        commit_hash=commit_hash,
        platforms=platforms
    )
    try:
        resp = api_key_model_verify_service.pre_check_to_verify_model(model_id, request_obj)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")



@pytest.mark.parametrize("task_id, expect_success", [(TASK_ID, False)])
def test_get_verify_platform_task_by_id(api_key_model_verify_service, task_id, expect_success):
    try:
        resp = api_key_model_verify_service.get_verify_platform_task_by_id(task_id)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")


@pytest.mark.parametrize("task_id, expect_success", [(TASK_ID, False)])
def test_get_model_versioning_by_task_id(api_key_model_verify_service, task_id, expect_success):
    try:
        resp = api_key_model_verify_service.get_model_versioning_by_task_id(task_id)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")



from aioz_api_client.models.response_success_response import ResponseSuccessResponse
from aioz_api_client.models.response_get_list_model_versioning_lite_response import ResponseGetListModelVersioningLiteResponse
from aioz_api_client.models.response_model_versioning_group_lite_response import ResponseModelVersioningGroupLiteResponse

class ApiKeyModelVersioningService:
    def __init__(self, api):
        self.api = api
        
    def delete_model_versioning_by_model_id_and_commit_hash(self, model_id: str, commit_hash: str)->ResponseSuccessResponse:
        path = f"api-key/model/{model_id}/versioning"
        params = {
            "commitHash": commit_hash
        }
        resp = self.api.request("DELETE", path, query_params=params,response_model=ResponseSuccessResponse)
        return resp


    def change_current_model_versioning_by_model_id_and_commit_hash(self, model_id: str, commit_hash: str)->ResponseSuccessResponse:
        path = f"api-key/model/{model_id}/versioning"
        params = {
            "commitHash": commit_hash
        }
        resp = self.api.request("PUT", path, query_params=params,response_model=ResponseSuccessResponse)
        return resp


    def get_list_verified_model_versioning(self, model_id: str, offset: int, limit: int, verify_status: str)->ResponseGetListModelVersioningLiteResponse:
        path = (
        f"api-key/model/{model_id}/versioning/list"
        f"?offset={offset}&limit={limit}&verifyStatus={verify_status}"
    )
        resp = self.api.request("GET", path,response_model=ResponseGetListModelVersioningLiteResponse)
        return resp

    def get_current_model_versioning_by_model_id(self, model_id: str)->ResponseModelVersioningGroupLiteResponse:
        path = f"api-key/model/{model_id}/versioning"
        resp = self.api.request("GET", path,response_model=ResponseModelVersioningGroupLiteResponse)
        return resp



import json
import pytest
from my_platform_sdk_package.http_client import ApiError
from aioz_api_client.models.request_distribute_task_request import RequestDistributeTaskRequest
from config import API_KEY, BASE_URL, MODEL_ID,LIMIT, OFFSET, TASK_ID, FROM, TO

@pytest.mark.parametrize(
    "limit, offset, expect_success",
    [
        (5, 0, True),
        (5, -99, False),
    ]
)
def test_get_task_histories(api_key_service, limit, offset, expect_success):
    try:
        resp = api_key_service.get_task_histories(limit=limit, offset=offset)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
    except ApiError as e:
        assert "Offset" in str(e), "Expected Offset validation error"

   

def test_get_balance(api_key_service):
    try:
        resp = api_key_service.get_balance()
        assert resp.status == "success"
        assert resp.data is not None
        assert hasattr(resp.data, "balance")
    except ApiError as e:
        pytest.fail(f"Unexpected APIError: {e}")



@pytest.mark.parametrize(
    "model_id, expect_success",
    [
        (MODEL_ID, False),
    ]
)
def test_create_task(api_key_service, model_id, expect_success):
    request = RequestDistributeTaskRequest(
        model_id=MODEL_ID,
        files=[
            {
                "key":"input",
                "data":"https://upload.wikimedia.org/wikipedia/commons/thumb/1/15/Cat_August_2010-4.jpg/1200px-Cat_August_2010-4.jpg",
                "name":"image.jpg"
            }
        ],
        input_params={}
    )

    if expect_success:
        try:
            resp = api_key_service.create_task(request)
            assert resp.status == "success"
            assert resp.data is not None
        except ApiError as e:
            pytest.fail(f"Unexpected APIError: {e}")


@pytest.mark.parametrize(
    "task_id, expect_success",
    [
        ("aea6944c-a808-4c11-b8de-557fe02d505f", False),
    ]
)
def test_get_task_result(api_key_service, task_id, expect_success):
    if expect_success:
        try:
            resp = api_key_service.get_task_result(task_id=task_id)
            assert resp.status == "success"
            assert resp.data is not None
        except ApiError as e:
            pytest.fail(f"Unexpected APIError: {e}")









import pytest
from my_platform_sdk_package.http_client import ApiError
from config import OWNER, REPO, PATH, SHA, PAGE, PAGE_SIZE, REPO_TYPE

@pytest.mark.parametrize(
    "owner, repo, expect_success",
    [
        (OWNER, REPO, False),
    ]
)
def test_get_commit_history(api_key_repository_service, owner, repo, expect_success):
    try:
        resp = api_key_repository_service.get_commit_history(
            owner_username=owner,
            repository_name=repo,
            path=PATH,
            sha=SHA,
            page=PAGE,
            page_size=PAGE_SIZE,
            repo_type=REPO_TYPE,
        )
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
    except ApiError as e:
        assert "repository not found" in str(e).lower(), \
                f"Expected 'repository not found' in error, got {e}"



from aioz_api_client.exceptions import ApiException
import json
from aioz_api_client.api_client import ApiClient
from my_platform_sdk_package.services.api_key_service import ApiKeyService
from my_platform_sdk_package.services.api_key_model_service import ApiKeyModelService
from my_platform_sdk_package.services.api_key_model_verify_service import ApiKeyModelVerifyService
from my_platform_sdk_package.services.api_key_model_versioning_service import ApiKeyModelVersioningService
from my_platform_sdk_package.services.api_key_repository_service import ApiKeyRepositoryService


BASE_URL = "http://143.198.81.10:9000/api/v1/"


class ApiError(Exception):
    def __init__(self, status, body):
        self.http_status = status
        self.raw_body = body

        try:
            parsed = json.loads(body)
            self.api_status = parsed.get("status")
            self.message = parsed.get("message")
        except Exception:
            self.api_status = None
            self.message = body
            parsed = {"status": status, "message": body}

        self.status = self.api_status or self.http_status
        self.parsed_body = parsed

        super().__init__(self.message)

    def __str__(self):
        return json.dumps(self.parsed_body, ensure_ascii=False)


class HttpClient:
    def __init__(self, api_key: str, base_url: str = BASE_URL):
        self.client = ApiClient()
        if api_key:
            self.client.set_default_header("x-api-key", api_key)
        if base_url:
            self.client.configuration.host = base_url

        self.api_key_service = ApiKeyService(self)
        self.api_key_model_service = ApiKeyModelService(self)
        self.api_key_model_verify_service = ApiKeyModelVerifyService(self)
        self.api_key_model_versioning_service = ApiKeyModelVersioningService(self)
        self.api_key_repository_service = ApiKeyRepositoryService(self)

    def request(
        self,
        method: str,
        path: str,
        query_params=None,
        body=None,
        headers=None,
        timeout: float = None,
        response_model=None
    ):
        headers = headers or {}
        if body is not None:
            headers["Content-Type"] = "application/json"

        method, url, header_params, body, post_params = self.client.param_serialize(
            method=method,
            resource_path=path,
            query_params=query_params,
            header_params=headers,
            body=body,
        )

        try:
            response = self.client.call_api(
                method=method,
                url=url,
                header_params=header_params,
                body=body,
                post_params=post_params,
                _request_timeout=timeout
            )
            response.read()
            deserialized = self.client.response_deserialize(
                response_data=response,
                response_types_map={"2XX": response_model or object}
            )
            return deserialized.data

        except ApiException as e:
            status_code = e.status
            body = e.body or ""
            raise ApiError(status_code, body) from e



from aioz_api_client.models.request_get_api_key_statistics_by_model_id_request import RequestGetApiKeyStatisticsByModelIdRequest
from aioz_api_client.models.request_distribute_task_request import RequestDistributeTaskRequest
from aioz_api_client.models.response_wallet_with_address_response import ResponseWalletWithAddressResponse
from aioz_api_client.models.response_distribute_task_response import ResponseDistributeTaskResponse
from aioz_api_client.models.response_get_task_statistics_response import ResponseGetTaskStatisticsResponse
from aioz_api_client.models.response_get_task_result_response import ResponseGetTaskResultResponse
from aioz_api_client.models.response_api_key_history_list_response import ResponseApiKeyHistoryListResponse
from aioz_api_client.models.response_get_api_key_permission_response import ResponseGetApiKeyPermissionResponse

class ApiKeyService:
    def __init__(self, api):
        self.api = api

    def get_balance(self) -> ResponseWalletWithAddressResponse:
        api_response = self.api.request(
            method="GET",
            path="api-key/balance",
            response_model=ResponseWalletWithAddressResponse
        )
        return api_response

    def create_task(self, request: RequestDistributeTaskRequest)->ResponseDistributeTaskResponse:
        path = "api-key/task"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseDistributeTaskResponse)
        return resp

    def get_api_key_statistics(self, request: RequestGetApiKeyStatisticsByModelIdRequest)->ResponseGetTaskStatisticsResponse:
        path = "api-key/statistics"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseGetTaskStatisticsResponse)
        return resp


    def get_task_result(self, task_id: str)->ResponseGetTaskResultResponse:
        path = f"api-key/task/{task_id}/result"
        resp = self.api.request("GET", path,response_model=ResponseGetTaskResultResponse)
        return resp
    
    def get_task_histories(self, limit: int, offset: int)->ResponseApiKeyHistoryListResponse:
        query_params = {
            "limit": limit,
            "offset": offset
        }
        resp = self.api.request("GET", "api-key/task/histories", query_params=query_params,response_model=ResponseApiKeyHistoryListResponse)
        return resp

    
    def get_api_key_permission(self)->ResponseGetApiKeyPermissionResponse:
        resp = self.api.request("GET", "api-key/permission",response_model=ResponseGetApiKeyPermissionResponse)
        return resp


import pytest
from my_platform_sdk_package.http_client import ApiError
from config import API_KEY, BASE_URL, MODEL_ID,LIMIT, OFFSET, TASK_ID, FROM, TO, COMMIT_HASH, VERIFY_STATUS
from aioz_api_client.models.request_get_api_key_statistics_by_model_id_request import RequestGetApiKeyStatisticsByModelIdRequest

@pytest.mark.parametrize("model_id, from_date, to_date, expect_success", [
    (MODEL_ID, FROM, TO, True)
])
def test_get_model_statistics(api_key_model_service, model_id, from_date, to_date, expect_success):
    request = RequestGetApiKeyStatisticsByModelIdRequest(var_from=from_date, to=to_date)
    try:
        resp= api_key_model_service.get_model_statistics(model_id, request)
        assert resp.status == "success"
        assert resp.data is not None
    except ApiError as e:
        pytest.fail(f"Unexpected APIError: {e}")
       

@pytest.mark.parametrize("model_id, expect_success", [
    (MODEL_ID, False),
])
def test_get_model_task_cost(api_key_model_service, model_id, expect_success):
    try:
        resp = api_key_model_service.get_model_task_cost(model_id)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")
        else:
            assert "don't have any version" in str(e).lower(), f"Expected version error, got {e}"

        
@pytest.mark.parametrize("model_id, expect_success", [
    (MODEL_ID, False)
])
def test_check_model_is_serving(api_key_model_service, model_id, expect_success):
    try:
        resp = api_key_model_service.check_model_is_serving(model_id)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")


@pytest.mark.parametrize("model_id, expect_success", [
    (MODEL_ID, True),
])
def test_get_model_info(api_key_model_service, model_id, expect_success):
    try:
        resp = api_key_model_service.get_model_info(model_id)
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")




@pytest.mark.parametrize("expect_success", [True])
def test_get_list_platforms_support(api_key_model_service, expect_success):
    try:
        resp = api_key_model_service.get_list_platforms_support()
        if expect_success:
            assert resp.status == "success"
            assert resp.data is not None
        else:
            pytest.fail("Expected ApiError but got success response")
    except ApiError as e:
        if expect_success:
            pytest.fail(f"Unexpected APIError: {e}")




from http_client import HttpClient, ApiError

API_KEY = "d9eb2842bb95039bfc31196432a82998bc5930f4"

if __name__ == "__main__":
    client = HttpClient(api_key=API_KEY)

    try:        
        resp = client.api_key_model_service.get_list_platforms_support()
        print(resp)
        print(resp.status)

    except ApiError as e:
        print(e)
        # print(e.status)
        # print(e.message)




from aioz_api_client.models.request_check_valid_to_verify_ai_model_request import RequestCheckValidToVerifyAiModelRequest
from aioz_api_client.models.request_verify_ai_model_request import RequestVerifyAiModelRequest
from aioz_api_client.models.request_calculate_cost_to_verify_ai_model_request import RequestCalculateCostToVerifyAiModelRequest
from aioz_api_client.models.response_estimate_cost_response import ResponseEstimateCostResponse
from aioz_api_client.models.response_verify_ai_model_response import ResponseVerifyAiModelResponse
from aioz_api_client.models.response_check_valid_to_verify_ai_model_response import ResponseCheckValidToVerifyAiModelResponse
from aioz_api_client.models.response_model_versioning_group_lite_list_response import ResponseModelVersioningGroupLiteListResponse
from aioz_api_client.models.response_queue_task_response import ResponseQueueTaskResponse
from aioz_api_client.models.response_model_versioning_response import ResponseModelVersioningResponse

class ApiKeyModelVerifyService:
    def __init__(self, api):
        self.api = api

    def calculate_cost_to_verify_model(self, model_id: str, request: RequestCalculateCostToVerifyAiModelRequest)->ResponseEstimateCostResponse:
        path = f"api-key/model/{model_id}/verify/cost"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseEstimateCostResponse)
        return resp

    def verify_model(self, model_id: str, request: RequestVerifyAiModelRequest)->ResponseVerifyAiModelResponse:
        path = f"api-key/model/{model_id}/verify"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseVerifyAiModelResponse)
        return resp


    def pre_check_to_verify_model(self, model_id: str, request: RequestCheckValidToVerifyAiModelRequest)->ResponseCheckValidToVerifyAiModelResponse:
        path = f"api-key/model/{model_id}/pre-verify"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseCheckValidToVerifyAiModelResponse)
        return resp



    def get_list_verify_model_task_by_commit_hash_and_status(self, model_id: str, commit_hash: str, status: str)->ResponseModelVersioningGroupLiteListResponse:
        path = f"api-key/model/{model_id}/verify/task"
        params = {"commitHash": commit_hash, "verifyStatus": status}
        resp = self.api.request("GET", path, query_params=params,response_model=ResponseModelVersioningGroupLiteListResponse)
        return resp

    def get_verify_platform_task_by_id(self, task_id: str)->ResponseQueueTaskResponse:
        path = f"api-key/model/verify/platform/task/{task_id}"
        resp = self.api.request("GET", path,response_model=ResponseQueueTaskResponse)
        return resp

    def get_model_versioning_by_task_id(self, task_id: str)->ResponseModelVersioningResponse:
        path = f"api-key/model/verify/hub/task/{task_id}"
        resp = self.api.request("GET", path,response_model=ResponseModelVersioningResponse)
        return resp



from typing import Optional
from aioz_api_client.models.response_get_commit_history_response import ResponseGetCommitHistoryResponse

class ApiKeyRepositoryService:
    def __init__(self, api):
        self.api = api

    def get_commit_history(
        self,
        owner_username: str,
        repository_name: str,
        path: Optional[str] = None,
        sha: Optional[str] = None,
        page: Optional[int] = 1,
        page_size: Optional[int] = 10,
        repo_type: Optional[str] = None
    )->ResponseGetCommitHistoryResponse:
        url_path = f"api-key/repository/{owner_username}/{repository_name}/commit/history"
        params = {}
        if path:
            params["path"] = path
        if sha:
            params["sha"] = sha
        if page is not None:
            params["page"] = page
        if page_size is not None:
            params["pageSize"] = page_size
        if repo_type:
            params["repoType"] = repo_type
        resp = self.api.request("GET", url_path, query_params=params,response_model=ResponseGetCommitHistoryResponse)
        return resp



from aioz_api_client.models.request_get_api_key_statistics_by_model_id_request import RequestGetApiKeyStatisticsByModelIdRequest
from aioz_api_client.models.response_get_task_statistics_response import ResponseGetTaskStatisticsResponse
from aioz_api_client.models.response_estimate_cost_response import ResponseEstimateCostResponse
from aioz_api_client.models.response_check_model_is_serving_response import ResponseCheckModelIsServingResponse
from aioz_api_client.models.response_api_key_info_response import ResponseApiKeyInfoResponse
from aioz_api_client.models.response_get_list_platform_support_response import ResponseGetListPlatformSupportResponse

class ApiKeyModelService:
    def __init__(self, api):
        self.api = api

    def get_model_statistics(self, model_id: str, request: RequestGetApiKeyStatisticsByModelIdRequest)->ResponseGetTaskStatisticsResponse:
        path = f"api-key/model/{model_id}/statistics"
        resp = self.api.request("POST", path, body=request.to_dict(),response_model=ResponseGetTaskStatisticsResponse)
        return resp

    
    def get_model_task_cost(self, model_id: str)->ResponseEstimateCostResponse:
        path = f"api-key/model/{model_id}/task/cost"
        resp = self.api.request("GET", path,response_model=ResponseEstimateCostResponse)
        return resp

    def check_model_is_serving(self, model_id: str)->ResponseCheckModelIsServingResponse:
        path = f"api-key/model/{model_id}/serving"
        resp = self.api.request("GET", path,response_model=ResponseCheckModelIsServingResponse)
        return resp
    

    def get_model_info(self, model_id: str)->ResponseApiKeyInfoResponse:
        path = f"api-key/model/{model_id}/info"
        resp = self.api.request("GET", path,response_model=ResponseApiKeyInfoResponse)
        return resp

    def get_list_platforms_support(self)->ResponseGetListPlatformSupportResponse:
        path = "api-key/model/verify/support/platforms"
        resp = self.api.request("GET", path,response_model=ResponseGetListPlatformSupportResponse)
        return resp